Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(451)

Unified Diff: mojo/shell/fetcher/about_fetcher_unittest.cc

Issue 1679573002: Move shell interfaces into the shell.mojom namespace. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delegate
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/shell/connect_to_application_params.h ('k') | mojo/shell/native_runner.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/shell/fetcher/about_fetcher_unittest.cc
diff --git a/mojo/shell/fetcher/about_fetcher_unittest.cc b/mojo/shell/fetcher/about_fetcher_unittest.cc
index 6eed303e532a4ea2de053d1d923bd1f20a1c0730..84878e9d48f31c8b9f7998a308eb248d6607b7d1 100644
--- a/mojo/shell/fetcher/about_fetcher_unittest.cc
+++ b/mojo/shell/fetcher/about_fetcher_unittest.cc
@@ -31,8 +31,8 @@ namespace shell {
namespace {
class TestContentHandler : public ApplicationDelegate,
- public InterfaceFactory<ContentHandler>,
- public ContentHandler {
+ public InterfaceFactory<mojom::ContentHandler>,
+ public mojom::ContentHandler {
public:
TestContentHandler() : response_number_(0) {}
~TestContentHandler() override {}
@@ -44,19 +44,19 @@ class TestContentHandler : public ApplicationDelegate,
// Overridden from ApplicationDelegate:
void Initialize(ApplicationImpl* app) override {}
bool AcceptConnection(ApplicationConnection* connection) override {
- connection->AddService<ContentHandler>(this);
+ connection->AddService<mojom::ContentHandler>(this);
return true;
}
- // Overridden from InterfaceFactory<ContentHandler>:
+ // Overridden from InterfaceFactory<mojom::ContentHandler>:
void Create(ApplicationConnection* connection,
- InterfaceRequest<ContentHandler> request) override {
+ InterfaceRequest<mojom::ContentHandler> request) override {
bindings_.AddBinding(this, std::move(request));
}
// Overridden from ContentHandler:
void StartApplication(
- InterfaceRequest<Application> application,
+ InterfaceRequest<mojom::Application> application,
URLResponsePtr response,
const Callback<void()>& destruct_callback) override {
response_number_++;
@@ -72,7 +72,7 @@ class TestContentHandler : public ApplicationDelegate,
size_t response_number_;
URLResponsePtr latest_response_;
- WeakBindingSet<ContentHandler> bindings_;
+ WeakBindingSet<mojom::ContentHandler> bindings_;
DISALLOW_COPY_AND_ASSIGN(TestContentHandler);
};
@@ -84,7 +84,8 @@ class TestLoader : public ApplicationLoader {
private:
// Overridden from ApplicationLoader:
- void Load(const GURL& url, InterfaceRequest<Application> request) override {
+ void Load(const GURL& url,
+ InterfaceRequest<mojom::Application> request) override {
app_.reset(new ApplicationImpl(delegate_, std::move(request)));
}
« no previous file with comments | « mojo/shell/connect_to_application_params.h ('k') | mojo/shell/native_runner.h » ('j') | no next file with comments »
@@ -44,19 +44,19 @@ class TestContentHandler : public ApplicationDelegate,
bindings_.AddBinding(this, std::move(request));
}
- // Overridden from ContentHandler:
+ // Overridden from mojom::ContentHandler:
void StartApplication(

Powered by Google App Engine
This is Rietveld 408576698